var ESTree = require("./estree");
var Parser = require("./parser/parser");
var flow_1 = require("./flow");
var dot_1 = require("./exporters/dot");
var json_1 = require("./exporters/json");
var object_1 = require("./exporters/object");
exports.default = {
    parse: parse,
    exportAsDot: dot_1.exportAsDot,
    exportAsJson: json_1.exportAsJson,
    exportAsObject: object_1.exportAsObject,
    EdgeType: flow_1.EdgeType,
    FlowNode: flow_1.FlowNode,
    NodeType: flow_1.NodeType
};
function parse(program, options) {
    if (!isObject(program) || !program.type) {
        throw Error("'program' must be an object with a 'type' property");
    }
    if (program.type !== ESTree.NodeType.Program) {
        throw Error("The node type '" + program.type + "' is not supported");
    }
    var options = normalizeParserOptions(options || {});
    return Parser.parse(program, options);
}
function isObject(value) {
    return typeof value === "object" && value !== null;
}
function normalizeParserOptions(options) {
    var passes = options.passes;
    return {
        passes: {
            removeTransitNodes: passes === true || passes && passes.removeTransitNodes,
            rewriteConstantConditionalEdges: passes === true || passes && passes.rewriteConstantConditionalEdges
        }
    };
}
